@@ -5,5 +5,5 @@
 
 ##-----------------------------------------------------------------------------
 ceil <- function(x)
-    ceiling(x);
+    ceiling(x)
 
