@@ -5,5 +5,5 @@
 
 ##-----------------------------------------------------------------------------
 fix <- function(A)
-    trunc(A);
+    trunc(A)
 
