@@ -5,5 +5,5 @@
 
 ##-----------------------------------------------------------------------------
 mod <- function(x, y)
-    x %% y;
+    x %% y
 
