@@ -10,6 +10,6 @@ rem <- function(x, y) {
           (x < 0 && y < 0))) {
         ans <- ans - y
     }
-    return(ans);
+    return(ans)
 }
 
